# Inter-rater reliability, descriptives

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(ICC)

df = read.csv('../data/ns1.csv', stringsAsFactors = TRUE)
sum(is.na(df$response))  # 0 NAs
# df = df[!is.na(df$response), ]

# Inter-rater reliability
iccs = data.frame(scale = levels(df$scale))
for (i in 1:nrow(iccs)) {
  iccs$ICC[i] = ICCest(sound, response, df[df$scale == iccs$scale[i], ])
}
iccs
#           scale       ICC
# 1    aggression 0.1802653
# 2 formidability 0.1613079
# 3        height 0.1976347
# 4         pitch 0.5984646
# 5     roughness 0.3066441
# 6        timbre 0.5870981


# Or simple correlations b/w individual and aggregated responses
ag = aggregate(response ~ sound + scale, df, median)
ag$sound_scale = paste0(ag$sound, '_', ag$scale)
df$sound_scale = paste0(df$sound, '_', df$scale)
scales = levels(df$scale)

sumTab = data.frame(subject = unique(df$subject), cor = NA)
sumTab[, scales] = NA
for (i in 1:nrow(sumTab)) {
  temp = df[df$subject == sumTab$subject[i], ]
  for (s in scales) {
    temp_s = temp[temp$scale == s, ]
    if (nrow(temp_s) > 0) {
      idx = match(temp_s$sound_scale, ag$sound_scale)
      sumTab[i, s] = cor(temp_s$response, ag$response[idx], use = 'pairwise.complete.obs')
    }
  }
  idx = match(temp$sound_scale, ag$sound_scale)
  # plot(temp$response, ag$response[idx])
  sumTab$cor[i] = cor(temp$response, ag$response[idx], use = 'pairwise.complete.obs')
  sumTab$nTrials[i] = nrow(temp)
  sumTab$time[i] = max(as.numeric(temp$time), na.rm = TRUE) / 60000
}
summary(sumTab)
apply(sumTab[, c('cor', scales)], 2, function(x) median(x, na.rm = TRUE))
#       cor    aggression formidability        height         pitch     roughness        timbre 
# 0.8501193     0.5622727     0.5349447     0.6011109     0.8525345     0.7437533     0.8560112 


# Summary stats of participants
summary(df)
sumTab = data.frame(subject = unique(df$subject))
paste0(colnames(df), collapse = "','")
addVars = c('sex', 'age')
for (i in 1:nrow(sumTab)) {
  idx = which(df$subject == sumTab$subject[i])[1]
  sumTab[i, addVars] = df[idx, addVars]
}
sumTab
write.csv(sumTab, '../data/participants_demographics.csv')
table(sumTab$sex)
# female   male  other 
#    104    195      2 
hist(sumTab$age)
mean(sumTab$age); sd(sumTab$age); range(sumTab$age)
# [1] 25.72757
# [1] 8.140774
# [1] 18 59



# correlations between scales
agCor = data.frame(sound = levels(df$sound))
for (i in 1:nrow(agCor)) {
  temp = df[df$sound == agCor$sound[i], ]
  for (s in scales) {
    agCor[i, s] = mean(temp$response[temp$scale == s])
  }
}
cor(agCor[, scales], use = 'pairwise.complete.obs')
#               aggression formidability     height      pitch  roughness     timbre
# aggression     1.0000000     0.6143683  0.2855672 -0.1101494  0.4548186 -0.1918791
# formidability  0.6143683     1.0000000  0.3753323 -0.2103319  0.5377226 -0.3252174
# height         0.2855672     0.3753323  1.0000000 -0.4807439  0.4276293 -0.5457486
# pitch         -0.1101494    -0.2103319 -0.4807439  1.0000000 -0.6532687  0.8884350
# roughness      0.4548186     0.5377226  0.4276293 -0.6532687  1.0000000 -0.6894806
# timbre        -0.1918791    -0.3252174 -0.5457486  0.8884350 -0.6894806  1.0000000

