## Analysis of accuracy and RT in all IAT experiments

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

source('iat_rules&labels.R')
library(brms)
library(ggplot2)
df = read.csv('../data/pooled.csv', stringsAsFactors = TRUE)
df = droplevels(df[df$responseTime > 0, ])  # exclude weird trials, if any
df$congruent = df$pair %in% c('largeCh', 'largeAM', 'largeSh')
table(df$experiment, df$congruent)

experiments = list(
  ch008 = 'Chaos (audio 008)',
  ch135 = 'Chaos (audio 135)',
  am059 = 'AM (audio 059)',
  am363 = 'AM (audio 363)',
  sh034 = 'Subh (audio 034)',
  sh594 = 'Subh (audio 594)'
)
exp_names_ordered = rev(unlist(experiments))

odds = function(p) p / (1 - p)

# # Descriptives: RT
if (FALSE) {
  length(unique(df$subject))

  df$modality = ifelse(substr(as.character(df$target), nchar(as.character(df$target)) - 2, nchar(as.character(df$target))) == 'png', 'visual', 'audio')
  table(df$modality)
  aggregate((responseTime < 500) ~ modality, df, function(x) mean(x) * 100)
  aggregate((responseTime < 600) ~ modality, df, function(x) mean(x) * 100)
  aggregate((responseTime < 700) ~ modality, df, function(x) mean(x) * 100)

  hist(df$responseTime[df$modality == 'visual' & df$responseTime < 2000])
  hist(df$responseTime[df$modality == 'audio' & df$responseTime < 2000])

  aggregate(correct ~ congruent + experiment, df, mean)
  boxplot(log(responseTime) ~ congruent + experiment, df)
}

##
## ACCURACY
##
# mod_ac = brm(correct ~ experiment * congruent + (congruent|subject) + (1|target), data = df, family = 'bernoulli', iter = 4000, warmup = 500, cores = 2, chains = 2, prior = set_prior('normal(0, 2)'))  # <1 h for 46K points, 4000 iter
# saveRDS(mod_ac, '../mod/mod_ac.RDS')
mod_ac = readRDS('../mod/mod_ac.RDS')

# summary(mod_ac)
# plot(mod_ac)
# pp_check(mod_ac)
# conditional_effects(mod_ac)

newdata = expand.grid(experiment = levels(df$experiment),
                      congruent =c(TRUE, FALSE))
fit_acc_contrast = fitted(mod_ac, newdata = newdata, re_formula = NA, summary = FALSE)
p_acc = data.frame(experiment = levels(df$experiment))
for (i in 1:nrow(p_acc)) {
  idx = which(newdata$experiment == p_acc$experiment[i])  # congruent, then incongruent
  diff_errors = odds(1 - fit_acc_contrast[, idx[2]]) /
    odds(1 - fit_acc_contrast[, idx[1]])  # incongruent / congruent
  p_acc[i, c('fit', 'lwr', 'upr')] = quantile(diff_errors, probs = c(.5, .025, .975))
}

for (i in 1:nrow(p_acc)) {
  p_acc$label1[i] = rules[[p_acc$experiment[i]]]$label_plot1
  p_acc$label2[i] = rules[[p_acc$experiment[i]]]$label_plot2
  p_acc$exper_fmtd[i] = experiments[[as.character(p_acc$experiment[i])]]
}
p_acc$label_final = ifelse(
  p_acc$lwr < 1,  # 95% CI overlaps with 0
  '',
  ifelse(p_acc$fit > 0, as.character(p_acc$label1), as.character(p_acc$label2))
)

# per subject
newdata_subj = expand.grid(experiment = levels(df$experiment),
                           congruent = c(TRUE, FALSE),
                           subject = levels(df$subject))
fit_acc_subj = fitted(mod_ac, newdata = newdata_subj,
                      re_formula = '~congruent|subject', summary = FALSE)
a_acc = expand.grid(experiment = levels(df$experiment),
                    subject = levels(df$subject),
                    diff_errors = NA)
for (i in 1:nrow(a_acc)) {
  idx = which(newdata_subj$experiment == a_acc$experiment[i] &
                newdata_subj$subject == a_acc$subject[i])
  diff_errors = odds(1 - fit_acc_subj[, idx[2]]) /
    odds(1 - fit_acc_subj[, idx[1]])
  a_acc[i, c('fit', 'lwr', 'upr')] = quantile(diff_errors, probs = c(.5, .025, .975))
  a_acc$exper_fmtd[i] = experiments[[as.character(a_acc$experiment[i])]]
}


##
## RESPONSE TIME
##
# range(df$responseTime)  # ms
# quantile(df$responseTime, probs = c(.9, .95, .99))
# hist(df$responseTime)
# hist(log(df$responseTime))

dfRT = df[df$correct == TRUE, ]  # analyze RT only in trials with correct response!
dfRT = dfRT[dfRT$responseTime < 5000 & dfRT$responseTime > 0, ]
boxplot(log(responseTime) ~ target, dfRT)

# mod_rt = brm(responseTime ~ experiment * congruent + (congruent|subject) + (1|target), data = dfRT, family = 'lognormal', iter = 4000, warmup = 500, cores = 2, chains = 2, prior = set_prior('normal(0, 2)'))  # very slow - ~3-4 h for 2000 iter when nrow(dfRT) = 50000
# saveRDS(mod_rt, '../mod/mod_rt.RDS')
mod_rt = readRDS('../mod/mod_rt.RDS')

# plot(mod_rt)
# summary(mod_rt)
# pp_check(mod_rt)
# conditional_effects(mod_rt)

fit_rt_contrast = fitted(mod_rt, newdata = newdata, re_formula = NA, summary = FALSE)
p_rt = data.frame(experiment = levels(df$experiment))
for (i in 1:nrow(p_rt)) {
  idx = which(newdata$experiment == p_rt$experiment[i])  # congruent, then incongruent
  diff_rt = fit_rt_contrast[, idx[2]] - fit_rt_contrast[, idx[1]]  # incongruent - congruent
  p_rt[i, c('fit', 'lwr', 'upr')] = quantile(diff_rt, probs = c(.5, .025, .975))
}

for (i in 1:nrow(p_rt)) {
  p_rt$label1[i] = rules[[p_rt$experiment[i]]]$label_plot1
  p_rt$label2[i] = rules[[p_rt$experiment[i]]]$label_plot2
  p_rt$exper_fmtd[i] = experiments[[as.character(p_rt$experiment[i])]]
}
p_rt$label_final = ifelse(
  p_rt$lwr * p_rt$upr < 0,  # 95% CI overlaps with 0
  '',
  ifelse(p_rt$fit > 0, as.character(p_rt$label1), as.character(p_rt$label2))
)

# per subject
fit_rt_subj = fitted(mod_rt, newdata = newdata_subj, re_formula = '~congruent|subject', summary = FALSE)
a_rt = expand.grid(experiment = levels(df$experiment),
                   subject = levels(df$subject),
                   diff_errors = NA)
for (i in 1:nrow(a_rt)) {
  idx = which(newdata_subj$experiment == a_rt$experiment[i] &
                newdata_subj$subject == a_rt$subject[i])
  diff_rt = fit_rt_subj[, idx[2]] - fit_rt_subj[, idx[1]]  # incongruent - congruent
  a_rt[i, c('fit', 'lwr', 'upr')] = quantile(diff_rt, probs = c(.5, .025, .975))
  a_rt$exper_fmtd[i] = experiments[[as.character(a_rt$experiment[i])]]
}


# Plot accuracy and RT together
p_acc$measure = 'Errors'
p_rt$measure = 'Response time'
p_both = rbind(p_acc, p_rt)
p_both$exper_fmtd = factor(p_both$exper_fmtd, levels = exp_names_ordered)

a_acc$measure = 'Errors'
a_rt$measure = 'Response time'
a_both = rbind(a_acc, a_rt)
a_both$exper_fmtd = factor(a_both$exper_fmtd, levels = exp_names_ordered)
p_both$fit_ci = soundgen:::reportCI(p_both[, c('fit', 'lwr', 'upr')])

chance = data.frame(measure = c('Errors', 'Response time'),
                    line_pos = c(1, 0))

for (i in 1:nrow(p_both)) {
  if (p_both$measure[i] == 'Errors') {
    p_both$clearRope[i] = p_both$lwr[i] > 1
  } else {
    p_both$clearRope[i] = p_both$lwr[i] > 0
  }
}

ggplot(p_both, aes(x = exper_fmtd, y = fit, ymin = lwr, ymax = upr, alpha = clearRope)) +
  geom_violin(data = a_both, aes(x = exper_fmtd, y = fit), inherit.aes = FALSE, col = 'white', fill = 'gray50', alpha = .5) +
  geom_pointrange(pch = 16, color = 'black', fill = 'black') +
  geom_hline(data = chance, aes(yintercept = line_pos), linetype = 2) +
  xlab('') +
  scale_y_continuous(name = '', n.breaks = 4, expand = c(0, 0)) +  # trans = 'pseudo_log', expand = c(0, 0)
  scale_alpha_discrete(range = c(.3, 1), guide = FALSE) +
  facet_wrap(~ measure, scales = 'free_x') +
  coord_flip() +
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave(filename = '../pix/00_plot_all.png', width = 8, height = 5.5, units = 'cm', dpi = 600)

p_both[, c('measure', 'exper_fmtd', 'fit_ci')]
