# Helper script for fine-tuning sound-specific parameters

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(soundgen)

targets = list.files('originals/22050', pattern = '.wav', full.names = TRUE)
pitchManual = read.csv('pitchManual_95.csv')

idx = 71  # go through targets one by one and fine-tune as needed
target = targets[idx]
pitch = eval(parse(text = paste0('c(', pitchManual$pitch[idx], ')')))
# strip the initial and terminal NAs, but preserve NAs in the middle (pauses b/w syllables)
idx_notNA = which(!is.na(pitch))
pitch = pitch[head(idx_notNA, 1) : tail(idx_notNA, 1)]
dur = 10 * length(pitch) # pitchManual$duration_noSilence[idx] * 1000

spectrogram(target)
playme(target)


## SET THE MANUAL PARS HERE
source('NLPsize_synth_parsPerSound.R')
pars_specific = c(
  list(  # copy-paste into the long list below
    # rolloff = c(rep(-10, 5), -20),
    # noise = c(-35, -25),
    # freqWindow = 200,
    # pitchSm = 5,
    # vocalTract = 13.5,
    # transEnv = FALSE,
    jitterDep = 2
  ),
  parsPerS[[basename(target)]]
)
if (!is.null(pars_specific$pitchSm)) {
  pitch = pitchSmoothPraat(pitch, bandwidth = pars_specific$pitchSm, 
                           samplingRate = 100, plot = F)
}
if (is.null(pars_specific$freqWindow)) 
  pars_specific$freqWindow = mean(pitch, na.rm = TRUE)

# synthesize to check
pars_i = c(
  pars_specific,
  pars_common[which(!names(pars_common) %in% names(pars_specific))]
)
s = do.call(soundgen, c(
  pars_i,
  list(
    sylLen = dur,
    pitch = pitch
  )
))
# spectrogram(s, 22050)
# playme(s, 22050)

sf = transplantFormants(
  donor = target,
  recipient = s,
  samplingRate = 22050,
  freqWindow = pars_specific$freqWindow, # mean(pitch, na.rm = TRUE),
  windowLength = 25, step = 5, dynamicRange = 120
)
# seewave::savewav(sf, f = 22050, filename = '~/Downloads/temp.wav')
if (is.null(pars_specific$transEnv)) {
  sf = transplantEnv(
    donor = target,
    recipient = sf,
    samplingRateR = 22050,
    windowLength = 100,
    method = 'hil'
  )
}

spectrogram(sf, 22050)
playme(sf, 22050)

# spectrogram(target)
# playme(target)

