## Code for synthesizing 82 vocalizations * 4 NLP conditions

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(soundgen)

## PREP
# Downsample the originals to 22050 Hz b/c some have a low original sampling rate
#for f in *.wav; do echo "Converting $f"; g=`basename $f .wav`; ffmpeg -i $f -ar 22050 22050/$g.wav || echo FAILED; done

# Manual pitch-tracking
# pitch_app()
pitchManual = read.csv('pitchManual_95.csv')

# Manual NLP detection
# formant_app()
nlpManual = read.csv('NLP_95.csv')

# Save spectrograms for inspection
# spectrogram('originals/22050', savePlots = 'originals/22050/spectrograms')


## Hyper-pars for the generation of NLPs
# subh
subRatio_props = c(.75, .2, .05)  # for subRatio = 2, 3 and 4
subDep_mean = 20
subDep_sd = 10
subDep_min = 10
subDep_max = 100
getSubDep = function(n = 1) {
  soundgen:::rnorm_truncated(n, subDep_mean, subDep_sd, low = subDep_min, high = subDep_max)
}
# hist(getSubDep(100))

# am
amFreq_mean = 90
amFreq_sd = 20
amFreq_min = 40
amFreq_max = 200
getAmFreq = function(n = 1) {
  soundgen:::rnorm_truncated(n, amFreq_mean, amFreq_sd, low = amFreq_min, high = amFreq_max)
}
# hist(getAmFreq(100))
amDep_mean = 45
amDep_sd = 10
amDep_min = 10
amDep_max = 80
getAmDep = function(n = 1) {
  soundgen:::rnorm_truncated(n, amDep_mean, amDep_sd, low = amDep_min, high = amDep_max)
}
# hist(getAmDep(100))

# chaos
jitterDep_mean = 2
jitterDep_sd = 1
jitterDep_min = .5
jitterDep_max = 4
getJitterDep = function(n = 1) {
  soundgen:::rnorm_truncated(n, jitterDep_mean, jitterDep_sd, low = jitterDep_min, high = jitterDep_max)
}
# hist(getJitterDep(100))



## SYNTHESIS
# targets
targets = list.files('originals/22050', pattern = '.wav', full.names = TRUE)
pars = vector('list', length(targets))
names(pars) = basename(targets)

# sound-specific pars (set manually - see NLPsize_manualTuning.R)
source('NLPsize_synth_parsPerSound.R')

time_start = proc.time()
for (i in 1:length(targets)) {  # length(targets)
  # i = which(basename(targets) == 'roar_F_026.wav')
  target = targets[i]
  pitch = eval(parse(text = paste0('c(', pitchManual$pitch[pitchManual$file == basename(target)], ')')))
  # strip the initial and terminal NAs, but preserve NAs in the 
  # middle (pauses b/w syllables)
  idx_notNA = which(!is.na(pitch))
  pitch = pitch[head(idx_notNA, 1) : tail(idx_notNA, 1)]
  dur = pitchManual$duration_noSilence[i] * 1000
  
  pars_specific = parsPerS[[basename(target)]]
  if (!is.null(pars_specific$pitchSm)) {
    pitch = pitchSmoothPraat(pitch, bandwidth = pars_specific$pitchSm, 
                             samplingRate = 100, plot = F)
  }
  if (is.null(pars_specific$freqWindow)) 
    pars_specific$freqWindow = mean(pitch, na.rm = TRUE)
  # spectrogram(target)
  # playme(target)
  
  # set and save sound-specific pars
  nlp = nlpManual[nlpManual$file == basename(target), ]
  nlp_time = subDep = amDep = jitterDep = numeric(0)
  for (r in 1:nrow(nlp)) {
    nlp_time = c(nlp_time, nlp$from[r], (nlp$from[r] + 1), 
                 nlp$to[r], (nlp$to[r] + 1))
    subDep = c(subDep, 0, getSubDep(2), 0)
    amDep = c(amDep, 0, getAmDep(2), 0)
    jitterDep = c(jitterDep, 0, getJitterDep(2), 0)
  }
  nlp_time = c(0, nlp_time, dur)
  subDep = c(0, subDep, 0)
  amDep = c(0, amDep, 0)
  jitterDep = c(0, jitterDep, 0)
  subRatio = sample(2:4, size = 1, prob = subRatio_props)
  amFreq = getAmFreq()
  pars[[basename(target)]] = list(
    nlp_time = nlp_time, 
    subRatio = subRatio, subDep = subDep,
    amFreq = amFreq, amDep = amDep,
    jitterDep = jitterDep
  )
  pars_i = c(
    pars_specific,
    pars_common[which(!names(pars_common) %in% 
                        names(pars_specific))]
  )
  
  # no NLPs
  s_none = do.call(soundgen, c(
    pars_i,
    list(
      sylLen = dur,
      pitch = pitch
    )
  ))
  # spectrogram(s_none, 22050)
  # playme(s_none, 22050)
  sf_none = transplantFormants(
    donor = target,
    recipient = s_none,
    samplingRate = 22050,
    freqWindow = pars_specific$freqWindow, 
    windowLength = 25, step = 5, dynamicRange = 120
  )
  if (is.null(pars_specific$transEnv)) {
    sf_none = transplantEnv(
      donor = target,
      recipient = sf_none,
      samplingRateR = 22050,
      windowLength = 50,
      method = 'peak'
    )
  }
  # spectrogram(sf_none, 22050)
  # playme(sf_none, 22050)
  seewave::savewav(
    sf_none, f = 22050, 
    filename = paste0('synthetic/', xfun::sans_ext(basename(target)), '_none.wav')
  )
  
  # subh
  s_subh = do.call(soundgen, c(
    pars_i,
    list(
      sylLen = dur,
      pitch = pitch,
      subRatio = subRatio,
      subDep = list(
        time = nlp_time,
        value = subDep
      )
    )
  ))
  # spectrogram(s_subh, 22050)
  # playme(s_subh, 22050)
  sf_subh = transplantFormants(
    donor = target,
    recipient = s_subh,
    samplingRate = 22050,
    freqWindow = 300, # mean(pitch, na.rm = TRUE)
    windowLength = 25, step = 5, dynamicRange = 120
  )
  if (is.null(parsPerS[[basename(target)]]$transEnv)) {
    sf_subh = transplantEnv(
      donor = target,
      recipient = sf_subh,
      samplingRateR = 22050,
      windowLength = 50,
      method = 'peak'
    )
  }
  # spectrogram(sf_subh, 22050)
  # playme(sf_subh, 22050)
  seewave::savewav(
    sf_subh, f = 22050, 
    filename = paste0('synthetic/', xfun::sans_ext(basename(target)), '_subh.wav')
  )
  
  # am
  s_am = do.call(soundgen, c(
    pars_i,
    list(
      sylLen = dur,
      pitch = pitch,
      amFreq = amFreq,
      amDep = list(
        time = nlp_time,
        value = amDep
      )
    )
  ))
  # spectrogram(s_am, 22050)
  # playme(s_am, 22050)
  sf_am = transplantFormants(
    donor = target,
    recipient = s_am,
    samplingRate = 22050,
    freqWindow = 300, # mean(pitch, na.rm = TRUE)
    windowLength = 25, step = 5, dynamicRange = 120
  )
  if (is.null(parsPerS[[basename(target)]]$transEnv)) {
    sf_am = transplantEnv(
      donor = target,
      recipient = sf_am,
      samplingRateR = 22050,
      windowLength = 50,
      method = 'hil'
    )
  }
  # spectrogram(sf_am, 22050)
  # playme(sf_am, 22050)
  seewave::savewav(
    sf_am, f = 22050, 
    filename = paste0('synthetic/', xfun::sans_ext(basename(target)), '_am.wav')
  )
  
  # chaos
  s_chaos = do.call(soundgen, c(
    pars_i[!names(pars_i) %in% c('jitterDep', 'shimmerDep')],
    list(
      sylLen = dur,
      pitch = pitch,
      jitterDep = list(
        time = nlp_time,
        value = jitterDep
      ),
      shimmerDep = list(
        time = nlp_time,
        value = jitterDep * 10
      )
    )
  ))
  # spectrogram(s_chaos, 22050)
  # playme(s_chaos, 22050)
  sf_chaos = transplantFormants(
    donor = target,
    recipient = s_chaos,
    samplingRate = 22050,
    freqWindow = 300, # mean(pitch, na.rm = TRUE)
    windowLength = 25, step = 5, dynamicRange = 120
  )
  if (is.null(parsPerS[[basename(target)]]$transEnv)) {
    sf_chaos = transplantEnv(
      donor = target,
      recipient = sf_chaos,
      samplingRateR = 22050,
      windowLength = 50,
      method = 'peak'
    )
  }
  # spectrogram(sf_chaos, 22050)
  # playme(sf_chaos, 22050)
  seewave::savewav(
    sf_chaos, f = 22050, 
    filename = paste0('synthetic/', xfun::sans_ext(basename(target)), '_chaos.wav')
  )
  reportTime(i = i, nIter = length(targets),
             time_start = time_start)
}

spectrogram('synthetic', ylim = c(0, 8), savePlots = 'synthetic/spectrograms')
spectrogram('synthetic', ylim = c(0, 8), savePlots = '')
