## A list of soundgen settings for each prototype vocalization

# NB: pitchSm is good for removing shaky f0 in original chaos; transEnv is best turned off when there are multiple syllables with noise in between, etc - hard to time precisely, leading to artifacts; freqWindow can be narrow when the original contains chaos or other noise (well-defined formants) and wide when the original contains only harmonics (the spectrum is just defined by sharp peaks at harmonics), otherwise set to ~mean f0

# soundgen settings common to all sounds
pars_common = list(
  rolloff = -12,
  rolloffKHz = 0,
  noise = -40,
  rolloffNoise = 0,
  jitterDep = .02,
  shimmerDep = 2,
  formants = NA,
  formantCeiling = 5,
  temperature = .01,
  tempEffects = list(specDep = 0),
  addSilence = 0,
  samplingRate = 22050,
  pitchSamplingRate = 22050,
  invalidArgAction = 'ignore',
  shortestEpoch = 100
)

# soundgen settings that are specific to each of 82 prototypes
# paste(basename(targets), '= list()', collapse = ', ')
parsPerS = list(
  cry_F_475.wav = list(
    rolloff = c(-9, -15),
    pitchSm = 10
  ), 
  cry_F_494.wav = list(
    rolloff = -15,
    noise = -30,
    transEnv = FALSE
  ), 
  moan_M_380.wav = list(
    rolloff = c(-10, -15),
    noise = -30
  ), 
  moan_M_381_p1.wav = list(
    rolloff = c(-10, -12),
    noise = c(-30, -20)
  ), 
  moan_M_381_p2.wav = list(
    rolloff = c(-8, -10),
    noise = -15
  ), 
  moan_M_383.wav = list(
    rolloff = c(-8, -10),
    noise = -35
  ), 
  roar_F_007.wav = list(
    rolloff = c(-8, -10),
    noise = -35,
    freqWindow = 200
  ), 
  roar_F_024.wav = list(
    rolloff = c(-8, -10),
    noise = -35,
    freqWindow = 400,
    vocalTract = 14,
    pitchSm = 5
  ), 
  roar_F_026.wav = list(
    rolloff = c(-15, -8, -25),
    freqWindow = 400,
    pitchSm = 5
  ), 
  roar_F_034.wav = list(
    freqWindow = 150
  ), 
  roar_F_039.wav = list(
    freqWindow = 150
  ), 
  roar_F_041.wav = list(
    vocalTract = 15
  ), 
  roar_F_043.wav = list(
    
  ), 
  roar_F_068.wav = list(
    vocalTract = 13
  ), 
  roar_F_159.wav = list(
    
  ), 
  roar_F_170.wav = list(
    freqWindow = 250
  ), 
  roar_F_353.wav = list(
    freqWindow = 150,
    pitchSm = 5
  ), 
  roar_F_356.wav = list(
    freqWindow = 150
  ), 
  roar_F_357.wav = list(
    freqWindow = 250
  ), 
  roar_M_001.wav = list(
    freqWindow = 250
  ), 
  roar_M_022.wav = list(
    rolloff = c(-12, -15),
    freqWindow = 150
  ), 
  roar_M_023.wav = list(
    rolloff = -15,
    noise = -25
  ), 
  roar_M_027.wav = list(
    freqWindow = 200,
    pitchSm = 5
  ), 
  roar_M_032.wav = list(
    
  ), 
  roar_M_055.wav = list(
    rolloff = -20,
    noise = -35,
    freqWindow = 200
  ), 
  roar_M_059.wav = list(
    rolloff = -14,
    noise = -35,
    freqWindow = 400
  ), 
  roar_M_062.wav = list(
    rolloff = -14,
    noise = -35,
    freqWindow = 200,
    pitchSm = 5
  ), 
  roar_M_064.wav = list(
    
  ), 
  roar_M_131.wav = list(
    rolloff = -17,
    noise = -35,
    freqWindow = 200
  ), 
  roar_M_134.wav = list(
    rolloff = c(-25, rep(-15, 12)),
    noise = -35,
    freqWindow = 200
  ), 
  roar_M_135.wav = list(
    rolloff = -20,
    noise = list(time = c(-20, 420), value = -30),
    freqWindow = 200
  ), 
  roar_M_136.wav = list(
    freqWindow = 200
  ), 
  roar_M_137.wav = list(
    noise = list(
      time = c(0, 1000, 1800),
      value = c(-30, -25, -20)
    ),
    rolloff = c(-12, -12 -25),
    freqWindow = 200
  ), 
  roar_M_173.wav = list(
    rolloff = c(-15, -25),
    noise = list(time = c(0, 620), value = -25),
    freqWindow = 100
  ), 
  roar_M_225.wav = list(
    noise = list(time = c(0, 900, 1100, 1320),
                 value = c(-25, -25, 0, 0)),
    freqWindow = 400
  ), 
  roar_M_317.wav = list(
    rolloff = -16,
    noise = -25,
    freqWindow = 200
  ), 
  roar_M_318.wav = list(
    freqWindow = 200
  ), 
  roar_M_319.wav = list(
    rolloff = -20,
    noise = -30,
    freqWindow = 200
  ), 
  roar_M_320.wav = list(
    pitchSm = 2
  ), 
  roar_M_321.wav = list(
    pitchSm = 3,
    rolloff = list(time = c(0, 800, 810, 870),
                   value = c(-14, -14, -25, -25)),
    noise = -45,
    freqWindow = 200
  ), 
  roar_M_361.wav = list(
    rolloff = c(-9, -13),
    pitchSm = 3,
    freqWindow = 200
  ), 
  roar_M_362.wav = list(
    freqWindow = 200
  ), 
  roar_M_363.wav = list(
    noise = list(time = c(0, 480), value = -20)
  ), 
  roar_M_364.wav = list(
    noise = list(time = c(0, 570), value = -20)
  ), 
  roar_M_365.wav = list(
    freqWindow = 200
  ), 
  roar_M_376.wav = list(
    rolloff = c(-12, -20),
    freqWindow = 200
  ), 
  roar_M_388.wav = list(
    freqWindow = 200
  ), 
  roar_M_567.wav = list(
    pitchSm = 5,
    noise = -60
  ), 
  roar_M_572.wav = list(
    noise = list(time = c(0, 1200), value = -30)
  ), 
  roar_M_575.wav = list(
    attackLen = c(50, 150),
    noise = list(time = c(0, 850), value = -40)
  ), 
  roar_M_578.wav = list(
    
  ), 
  roar_M_582.wav = list(
    freqWindow = 200
  ), 
  roar_M_583.wav = list(
    freqWindow = 200,
    pitchSm = 5
  ), 
  roar_M_585.wav = list(
    rolloff = list(time = c(0, 1300, 1350, 1520),
                   value = c(-9, -9, -25, -25)),
    noise = c(-35, -25),
    pitchSm = 5
  ), 
  roar_M_594.wav = list(
    rolloff = c(-12, -15),
    noise = list(time = c(0, 480), value = -30),
    pitchSm = 5,
    freqWindow = 200
  ), 
  roar_M_595.wav = list(
    freqWindow = 200
  ), 
  roar_M_597.wav = list(
    freqWindow = 200
  ), 
  roar_M_601.wav = list(
    freqWindow = 200
  ), 
  roar_M_603.wav = list(

  ), 
  scream_F_008.wav = list(
    rolloff = -3,
    vocalTract = 14,
    mouth = c(.2, .6, .6, .6, .2),
    transEnv = FALSE  # b/c of clipping
  ), 
  scream_F_009.wav = list(
    rolloff = -3,
    vocalTract = 14,
    mouth = c(.2, .6, .6, .6, .2),
    transEnv = FALSE  # b/c of clipping
  ), 
  scream_F_030.wav = list(
    
  ), 
  scream_F_031.wav = list(
    rolloff = -3,
    vocalTract = 14,
    mouth = c(.2, .6, .6, .6, .2)
  ), 
  scream_F_203.wav = list(
    transEnv = FALSE  # b/c of the weird end
  ), 
  scream_F_212.wav = list(
    freqWindow = 500,
    vocalTract = 14
  ), 
  scream_F_213_p1.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 13
  ), 
  scream_F_213_p2.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 13
  ), 
  scream_F_215.wav = list(
    rolloff = -3,
    freqWindow = 1500,
    vocalTract = 13
  ), 
  scream_F_217.wav = list(
    rolloff = -3,
    freqWindow = 1500,
    vocalTract = 15
  ), 
  scream_F_240.wav = list(
    rolloff = -3,
    freqWindow = 500
  ), 
  scream_F_241.wav = list(
    rolloff = -3,
    freqWindow = 1500,
    vocalTract = 14.5
  ), 
  scream_F_244.wav = list(
    rolloff = -3,
    freqWindow = 1500,
    vocalTract = 14.5
  ), 
  scream_F_322.wav = list(
    rolloff = list(time = c(0, 600, 620, 800), 
                   value = c(-3, -3, -25, -25)),
    freqWindow = 1500,
    vocalTract = 14.5,
    transEnv = FALSE
  ), 
  scream_F_324.wav = list(
    rolloff = c(-3, -3, -15),
    freqWindow = 1000,
    vocalTract = 15
  ), 
  scream_F_325.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 14
  ), 
  scream_F_326.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 14
  ), 
  scream_F_327.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 15,
    noise = list(time = c(-200, 2050), value = -30)
  ), 
  scream_F_328.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 15,
    noise = list(time = c(0, 630), value = -30)
  ), 
  scream_F_332.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 14
  ), 
  scream_F_336.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 14.5
  ), 
  scream_F_346.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 14.5
  ), 
  scream_F_347.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 14
  ), 
  scream_F_406.wav = list(
    rolloff = c(-15, rep(-3, 8)),
    freqWindow = 2000,
    vocalTract = 14
  ), 
  scream_F_417.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 14
  ), 
  scream_F_421.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 15.5
  ), 
  scream_F_423.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 15.5
  ), 
  scream_F_570.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 14
  ), 
  scream_M_053.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 16
  ), 
  scream_M_198.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 16
  ), 
  scream_M_199.wav = list(
    rolloff = -3,
    freqWindow = 500,
    vocalTract = 15.5
  ), 
  scream_M_224.wav = list(
    rolloff = -3,
    freqWindow = 1000,
    vocalTract = 15
  ), 
  scream_M_242.wav = list(
    freqWindow = 200
  ), 
  scream_M_374.wav = list(
    freqWindow = 200
  ), 
  scream_M_378.wav = list(
    rolloff = c(rep(-12, 8), -30),
    freqWindow = 200
  )
)
